@@ -4,6 +4,7 @@ import pprint
 from typing import Any
 from typing import Dict
 from typing import Hashable
+from typing import List
 from typing import Optional
 from typing import Tuple
 
@@ -12,6 +13,7 @@ import pandas as pd
 
 from art import tprint
 from lmfit import Minimizer
+from lmfit import Parameters
 from lmfit import conf_interval
 from lmfit import report_ci
 from lmfit import report_fit
@@ -110,21 +112,19 @@ class RegressionMetrics:
             Tuple[NDArray[np.float64], NDArray[np.float64]]: Tuple of true and predicted
                 (fit) intensities.
         """
-        _true = df[
+        true = df[
             [col_name for col_name in df.columns if name_true in col_name]
         ].to_numpy()
 
-        _pred = df[
+        pred = df[
             [col_name for col_name in df.columns if name_pred in col_name]
         ].to_numpy()
 
-        if _pred.shape != _true.shape:
+        if pred.shape != true.shape:
             raise ValueError("The shape of the real and fit data-values are not equal!")
 
         return (
-            (_true, _pred)
-            if _true.shape[1] > 1
-            else (np.array([_true]), np.array([_pred]))
+            (true, pred) if true.shape[1] > 1 else (np.array([true]), np.array([pred]))
         )
 
     def __call__(self) -> Dict[Hashable, Any]:
@@ -182,7 +182,7 @@ def fit_report_as_dict(
     result = inpars
     params = inpars.params
 
-    parnames = list(params.keys())
+    parnames: List[str] = list(params.keys())
 
     buffer: Dict[str, Dict[Any, Any]] = {
         "configurations": {},
@@ -192,35 +192,10 @@ def fit_report_as_dict(
         "correlations": {},
         "covariance_matrix": {},
     }
-    if result is not None:
 
-        buffer["configurations"]["fitting_method"] = result.method
-        buffer["configurations"]["function_evals"] = result.nfev
-        buffer["configurations"]["data_points"] = result.ndata
-        buffer["configurations"]["variable_names"] = result.var_names
-        buffer["configurations"]["variable_numbers"] = result.nvarys
-        buffer["configurations"]["degree_of_freedom"] = result.nfree
-
-        buffer["statistics"]["chi-square"] = result.chisqr
-        buffer["statistics"]["reduced_chi_square"] = result.redchi
-        buffer["statistics"]["akaike_information"] = result.aic
-        buffer["statistics"]["bayesian_information"] = result.bic
-
-        if not result.errorbars:
-            print("##  Warning: uncertainties could not be estimated:")
-            if result.method not in ("leastsq", "least_squares"):
-                print(
-                    f"The fitting method '{result.method}' does not natively calculate"
-                    " and uncertainties cannot be estimated due to be out of region!"
-                )
-
-            parnames_varying = [par for par in result.params if result.params[par].vary]
-            for name in parnames_varying:
-                par = params[name]
-                if par.init_value and np.allclose(par.value, par.init_value):
-                    buffer["errorbars"]["at_initial_value"] = name
-                if np.allclose(par.value, par.min) or np.allclose(par.value, par.max):
-                    buffer["errorbars"]["at_boundary"] = name
+    result, buffer, params = _extracted_gof_from_results(
+        result=result, buffer=buffer, params=params
+    )
     for name in parnames:
         par = params[name]
         buffer["variables"][name] = {}
@@ -259,17 +234,61 @@ def fit_report_as_dict(
                     and abs(par.correl[name_2]) <= 1.0
                 ):
                     buffer["correlations"][name_1][name_2] = par.correl[name_2]
-    try:
+
+    if result.covar is not None and result.covar.shape[0] == len(parnames):
         for i, name_1 in enumerate(parnames):
             buffer["covariance_matrix"][name_1] = {
                 name_2: result.covar[i, j] for j, name_2 in enumerate(parnames)
             }
-
-    except (AttributeError, IndexError) as exc:
-        print(f"{exc}: Covariance Matrix could not be calculated.\n")
     return buffer
 
 
+def _extracted_gof_from_results(
+    result: minimize, buffer: Dict[str, Any], params: Parameters
+) -> Tuple[minimize, Dict[str, Any], Parameters]:
+    """Extract the goodness of fit from the results.
+
+    Args:
+        result (minimize): Input Parameters from a fit or the  Minimizer results
+        buffer (Dict[str, Any]): The buffer to store the results.
+        params (Parameters): The parameters of the fit.
+
+    Returns:
+        minimize: The results.
+        Dict[str, Any]: The buffer with updated results.
+        Parameters: The parameters.
+    """
+    if result is not None:
+        buffer["configurations"]["fitting_method"] = result.method
+        buffer["configurations"]["function_evals"] = result.nfev
+        buffer["configurations"]["data_points"] = result.ndata
+        buffer["configurations"]["variable_names"] = result.var_names
+        buffer["configurations"]["variable_numbers"] = result.nvarys
+        buffer["configurations"]["degree_of_freedom"] = result.nfree
+
+        buffer["statistics"]["chi-square"] = result.chisqr
+        buffer["statistics"]["reduced_chi_square"] = result.redchi
+        buffer["statistics"]["akaike_information"] = result.aic
+        buffer["statistics"]["bayesian_information"] = result.bic
+
+        if not result.errorbars:
+            print("##  Warning: uncertainties could not be estimated:")
+            if result.method not in ("leastsq", "least_squares"):
+                print(
+                    f"The fitting method '{result.method}' does not natively calculate"
+                    " and uncertainties cannot be estimated due to be out of region!"
+                )
+
+            parnames_varying = [par for par in result.params if result.params[par].vary]
+            for name in parnames_varying:
+                par = params[name]
+                if par.init_value and np.allclose(par.value, par.init_value):
+                    buffer["errorbars"]["at_initial_value"] = name
+                if np.allclose(par.value, par.min) or np.allclose(par.value, par.max):
+                    buffer["errorbars"]["at_boundary"] = name
+    return result, buffer, params
+
+
 class PrintingResults:
     """Print the results of the fitting process."""
 
@@ -319,43 +338,86 @@ class PrintingResults:
     @property
     def printing_regular_mode(self) -> None:
         """Print the fitting results in the regular mode."""
+        self.print_statistic()
+        self.print_fit_results()
+        self.print_confidence_interval()
+        self.print_linear_correlation()
+        self.print_regression_metrics()
+
+    def print_statistic(self) -> None:
+        """Print the statistic."""
         print("\nStatistic:\n")
         self.print_tabulate(args=self.args["data_statistic"])
 
+    def print_fit_results(self) -> None:
+        """Print the fit results."""
         print("\nFit Results and Insights:\n")
         print(
             report_fit(self.result, modelpars=self.result.params, **self.args["report"])
         )
+
+    def print_confidence_interval(self) -> None:
+        """Print the confidence interval."""
+        print("\nConfidence Interval:\n")
         if self.args["conf_interval"]:
-            print("\nConfidence Interval:\n")
             try:
                 report_ci(
                     conf_interval(
                         self.minimizer, self.result, **self.args["conf_interval"]
                     )
                 )
-            except MinimizerException as exc:
+            except (MinimizerException, ValueError) as exc:
                 print(f"Error: {exc} -> No confidence interval could be calculated!")
                 self.args["confidence_interval"] = {}
+
+    def print_linear_correlation(self) -> None:
+        """Print the linear correlation."""
         print("\nOverall Linear-Correlation:\n")
         self.print_tabulate(args=self.args["linear_correlation"])
+
+    def print_regression_metrics(self) -> None:
+        """Print the regression metrics."""
         print("\nRegression Metrics:\n")
         self.print_tabulate(args=self.args["regression_metrics"])
 
     @property
     def printing_verbose_mode(self) -> None:
         """Print all results in verbose mode."""
+        self.print_statistic_verbose()
+        self.print_input_parameters_verbose()
+        self.print_fit_results_verbose()
+        self.print_confidence_interval_verbose()
+        self.print_linear_correlation_verbose()
+        self.print_regression_metrics_verbose()
+
+    def print_statistic_verbose(self) -> None:
+        """Print the data statistic in verbose mode."""
         print("\nStatistic:\n")
         pp.pprint(self.args["data_statistic"])
+
+    def print_input_parameters_verbose(self) -> None:
+        """Print input parameters in verbose mode."""
         print("Input Parameter:\n")
         pp.pprint(self.args)
+
+    def print_fit_results_verbose(self) -> None:
+        """Print fit results in verbose mode."""
         print("\nFit Results and Insights:\n")
         pp.pprint(self.args["fit_insights"])
+
+    def print_confidence_interval_verbose(self) -> None:
+        """Print confidence interval in verbose mode."""
         if self.args["conf_interval"]:
             print("\nConfidence Interval:\n")
             pp.pprint(self.args["confidence_interval"])
+
+    def print_linear_correlation_verbose(self) -> None:
+        """Print overall linear-correlation in verbose mode."""
         print("\nOverall Linear-Correlation:\n")
         pp.pprint(self.args["linear_correlation"])
+
+    def print_regression_metrics_verbose(self) -> None:
+        """Print regression metrics in verbose mode."""
         print("\nRegression Metrics:\n")
         pp.pprint(self.args["regression_metrics"])
 
